@@ -25,7 +25,6 @@
 #include "userlayoutmodel.h"
 #include "workspace_options.h"
 #include "x11_helper.h"
-#include "xkb_rules.h"
 #include "xkboptionsmodel.h"
 
 #include "debug.h"
@@ -33,17 +32,18 @@
 KCMKeyboard::KCMKeyboard(QObject *parent, const KPluginMetaData &data)
     : KQuickManagedConfigModule(parent, data)
     , m_data(new KeyboardSettingsData(this))
-    , m_rules(Rules::readRules(Rules::READ_EXTRAS))
     , m_config(new KeyboardConfig(m_data->keyboardSettings(), this))
-    , m_layoutModel(new LayoutModel(m_rules, this))
-    , m_userLayoutModel(new UserLayoutModel(m_rules, m_config, this))
-    , m_keyboardModel(new KeyboardModel(m_rules, this))
+    , m_layoutModel(new LayoutModel(this))
+    , m_userLayoutModel(new UserLayoutModel(m_config, this))
+    , m_keyboardModel(new KeyboardModel(this))
     , m_shortcutHelper(new ShortcutHelper(this))
-    , m_xkbOptionsModel(new XkbOptionsModel(m_rules, this))
+    , m_xkbOptionsModel(new XkbOptionsModel(this))
 {
-    qmlRegisterAnonymousType<WorkspaceOptions>("org.kde.plasma.keyboard.kcm", 0);
-    qmlRegisterAnonymousType<KeyboardMiscSettings>("org.kde.plasma.keyboard.kcm", 0);
-    qmlRegisterAnonymousType<KeyboardSettings>("org.kde.plasma.keyboard.kcm", 0);
+    const auto uri = "org.kde.plasma.private.kcm_keyboard";
+    qmlRegisterAnonymousType<WorkspaceOptions>(uri, 1);
+    qmlRegisterAnonymousType<KeyboardMiscSettings>(uri, 1);
+    qmlRegisterAnonymousType<KeyboardSettings>(uri, 1);
+    qmlRegisterUncreatableMetaObject(NumLockState::staticMetaObject, uri, 1, 0, "NumLockState", QString());
 
     connect(m_data->keyboardSettings(), &KeyboardSettings::configureLayoutsChanged, this, [this]() -> void {
         if (m_data->keyboardSettings()->configureLayouts()) {
@@ -155,7 +155,7 @@ void KCMKeyboard::load()
     m_shortcutHelper->load();
     m_xkbOptionsModel->setXkbOptions(m_data->keyboardSettings()->xkbOptions());
     m_config->load();
-    m_shortcutHelper->actionColletion()->loadLayoutShortcuts(m_config->layouts(), m_rules);
+    m_shortcutHelper->actionColletion()->loadLayoutShortcuts(m_config->layouts());
     m_userLayoutModel->reset();
 }
 
@@ -179,7 +179,7 @@ void KCMKeyboard::save()
     m_data->keyboardSettings()->setXkbOptions(options);
     m_data->keyboardSettings()->save();
 
-    m_shortcutHelper->actionColletion()->setLayoutShortcuts(m_config->layouts(), m_rules);
+    m_shortcutHelper->actionColletion()->setLayoutShortcuts(m_config->layouts());
     m_config->save();
     m_userLayoutModel->reset();
 
@@ -204,7 +204,7 @@ void KCMKeyboard::resetShortcuts()
     settingsChanged();
 
     m_shortcutHelper->actionColletion()->resetLayoutShortcuts();
-    m_shortcutHelper->actionColletion()->setLayoutShortcuts(m_config->layouts(), m_rules);
+    m_shortcutHelper->actionColletion()->setLayoutShortcuts(m_config->layouts());
 }
 
 #include "kcm_keyboard.moc"
