@@ -26,7 +26,7 @@
 
 static QStringList buildActionId(const QString &componentUnique, const QString &componentFriendly, const QString &actionUnique, const QString &actionFriendly)
 {
-    QStringList actionId{"", "", "", ""};
+    QStringList actionId(4);
     actionId[KGlobalAccel::ComponentUnique] = componentUnique;
     actionId[KGlobalAccel::ComponentFriendly] = componentFriendly;
     actionId[KGlobalAccel::ActionUnique] = actionUnique;
@@ -318,7 +318,7 @@ void GlobalAccelModel::addApplication(const QString &desktopFileName, const QStr
     // Register a dummy action to trigger kglobalaccel to parse the desktop file
     QStringList actionId = buildActionId(desktopName, displayName, QString(), QString());
     m_globalAccelInterface->doRegister(actionId);
-    m_globalAccelInterface->unRegister(actionId);
+    m_globalAccelInterface->unregister(desktopName, QString());
     QCollator collator;
     collator.setCaseSensitivity(Qt::CaseInsensitive);
     collator.setNumericMode(true);
@@ -351,6 +351,7 @@ void GlobalAccelModel::addApplication(const QString &desktopFileName, const QStr
             auto c = loadComponent(infoReply.value());
             m_components.insert(pos, c);
             endInsertRows();
+            Q_EMIT applicationAdded(c);
         });
     });
 }
