@@ -5,11 +5,9 @@
 */
 
 #include "kwin_wl_backend.h"
-#include "kwin_wl_device.h"
 
 #include <algorithm>
 
-#include <KConfigGroup>
 #include <KLocalizedString>
 #include <KSharedConfig>
 
@@ -23,13 +21,12 @@
 
 KWinWaylandBackend::KWinWaylandBackend(QObject *parent)
     : InputBackend(parent)
-{
-    m_deviceManager = new QDBusInterface(QStringLiteral("org.kde.KWin"),
+    , m_deviceManager(new QDBusInterface(QStringLiteral("org.kde.KWin"),
                                          QStringLiteral("/org/kde/KWin/InputDevice"),
                                          QStringLiteral("org.kde.KWin.InputDeviceManager"),
                                          QDBusConnection::sessionBus(),
-                                         this);
-
+                                         this))
+{
     findDevices();
 
     m_deviceManager->connection().connect(QStringLiteral("org.kde.KWin"),
@@ -44,12 +41,12 @@ KWinWaylandBackend::KWinWaylandBackend(QObject *parent)
                                           QStringLiteral("deviceRemoved"),
                                           this,
                                           SLOT(onDeviceRemoved(QString)));
+
+    connect(this, &InputBackend::buttonMappingChanged, this, &InputBackend::needsSaveChanged);
 }
 
 KWinWaylandBackend::~KWinWaylandBackend()
 {
-    qDeleteAll(m_devices);
-    delete m_deviceManager;
 }
 
 void KWinWaylandBackend::findDevices()
@@ -78,71 +75,81 @@ void KWinWaylandBackend::findDevices()
                 continue;
             }
 
-            KWinWaylandDevice *dev = new KWinWaylandDevice(sn);
+            auto dev = std::make_unique<KWinWaylandDevice>(sn);
             if (!dev->init()) {
                 qCCritical(KCM_MOUSE) << "Error on creating device object" << sn;
                 m_errorString = i18n("Critical error on reading fundamental device infos of %1.", sn);
                 return;
             }
-            m_devices.append(dev);
+            connect(dev.get(), &KWinWaylandDevice::needsSaveChanged, this, &InputBackend::needsSaveChanged);
             qCDebug(KCM_MOUSE).nospace() << "Device found: " << dev->name() << " (" << dev->sysName() << ")";
+            m_devices.push_back(std::move(dev));
         }
     }
 }
 
-bool KWinWaylandBackend::applyConfig()
+bool KWinWaylandBackend::forAllDevices(bool (KWinWaylandDevice::*f)()) const
 {
-    KConfigGroup buttonGroup = KSharedConfig::openConfig(QStringLiteral("kcminputrc"))->group(QStringLiteral("ButtonRebinds")).group(QStringLiteral("Mouse"));
-    for (auto it = m_buttonMapping.cbegin(); it != m_buttonMapping.cend(); ++it) {
-        if (auto keys = it.value().value<QKeySequence>(); !keys.isEmpty()) {
-            buttonGroup.writeEntry(it.key(), QStringList{"Key", keys.toString(QKeySequence::PortableText)}, KConfig::Notify);
+    bool ok = true;
+    for (const auto &device : std::as_const(m_devices)) {
+        ok &= (device.get()->*f)();
+    }
+    return ok;
+}
+
+KConfigGroup KWinWaylandBackend::mouseButtonRebindsConfigGroup()
+{
+    return KSharedConfig::openConfig(u"kcminputrc"_s)->group(u"ButtonRebinds"_s).group(u"Mouse"_s);
+}
+
+bool KWinWaylandBackend::save()
+{
+    KConfigGroup buttonGroup = mouseButtonRebindsConfigGroup();
+
+    for (const auto &[buttonName, variant] : std::as_const(m_buttonMapping).asKeyValueRange()) {
+        if (const auto keySequence = variant.value<QKeySequence>(); !keySequence.isEmpty()) {
+            const auto value = QStringList{u"Key"_s, keySequence.toString(QKeySequence::PortableText)};
+            buttonGroup.writeEntry(buttonName, value, KConfig::Notify);
         } else {
-            buttonGroup.deleteEntry(it.key(), KConfig::Notify);
+            buttonGroup.deleteEntry(buttonName, KConfig::Notify);
         }
     }
 
-    return std::all_of(m_devices.constBegin(), m_devices.constEnd(), [](QObject *t) {
-        return static_cast<KWinWaylandDevice *>(t)->applyConfig();
-    });
+    return forAllDevices(&KWinWaylandDevice::save);
 }
 
-bool KWinWaylandBackend::getConfig()
+bool KWinWaylandBackend::load()
 {
     m_loadedButtonMapping.clear();
-    const KConfigGroup buttonGroup =
-        KSharedConfig::openConfig(QStringLiteral("kcminputrc"))->group(QStringLiteral("ButtonRebinds")).group(QStringLiteral("Mouse"));
+    const KConfigGroup buttonGroup = mouseButtonRebindsConfigGroup();
+
     for (int i = 1; i <= 24; ++i) {
-        const QString buttonName = QLatin1String("ExtraButton%1").arg(QString::number(i));
-        auto entry = buttonGroup.readEntry(buttonName, QStringList());
+        const auto buttonName = QLatin1String("ExtraButton%1").arg(QString::number(i));
+        const auto entry = buttonGroup.readEntry(buttonName, QStringList());
         if (entry.size() == 2 && entry.first() == QLatin1String("Key")) {
-            auto keys = QKeySequence::fromString(entry.at(1), QKeySequence::PortableText);
-            if (!keys.isEmpty()) {
-                m_loadedButtonMapping.insert(buttonName, keys);
+            if (const auto keySequence = QKeySequence::fromString(entry.at(1), QKeySequence::PortableText); !keySequence.isEmpty()) {
+                m_loadedButtonMapping.insert(buttonName, keySequence);
             }
         }
     }
     setButtonMapping(m_loadedButtonMapping);
 
-    return std::all_of(m_devices.constBegin(), m_devices.constEnd(), [](QObject *t) {
-        return static_cast<KWinWaylandDevice *>(t)->init();
-    });
+    return forAllDevices(&KWinWaylandDevice::init);
 }
 
-bool KWinWaylandBackend::getDefaultConfig()
+bool KWinWaylandBackend::defaults()
 {
-    return std::all_of(m_devices.constBegin(), m_devices.constEnd(), [](QObject *t) {
-        return static_cast<KWinWaylandDevice *>(t)->getDefaultConfig();
-    });
+    return forAllDevices(&KWinWaylandDevice::defaults);
 }
 
-bool KWinWaylandBackend::isChangedConfig() const
+bool KWinWaylandBackend::isSaveNeeded() const
 {
-    return m_buttonMapping != m_loadedButtonMapping || std::any_of(m_devices.constBegin(), m_devices.constEnd(), [](QObject *t) {
-               return static_cast<KWinWaylandDevice *>(t)->isChangedConfig();
+    return m_buttonMapping != m_loadedButtonMapping || std::ranges::any_of(std::as_const(m_devices), [](const std::unique_ptr<KWinWaylandDevice> &device) {
+               return device->isSaveNeeded();
            });
 }
 
-QVariantMap KWinWaylandBackend::buttonMapping()
+QVariantMap KWinWaylandBackend::buttonMapping() const
 {
     return m_buttonMapping;
 }
@@ -157,8 +164,8 @@ void KWinWaylandBackend::setButtonMapping(const QVariantMap &mapping)
 
 void KWinWaylandBackend::onDeviceAdded(QString sysName)
 {
-    if (std::any_of(m_devices.constBegin(), m_devices.constEnd(), [sysName](QObject *t) {
-            return static_cast<KWinWaylandDevice *>(t)->sysName() == sysName;
+    if (std::ranges::any_of(std::as_const(m_devices), [sysName](const std::unique_ptr<KWinWaylandDevice> &device) {
+            return device->sysName() == sysName;
         })) {
         return;
     }
@@ -176,45 +183,64 @@ void KWinWaylandBackend::onDeviceAdded(QString sysName)
             return;
         }
 
-        KWinWaylandDevice *dev = new KWinWaylandDevice(sysName);
+        auto dev = std::make_unique<KWinWaylandDevice>(sysName);
         if (!dev->init()) {
             Q_EMIT deviceAdded(false);
             return;
         }
 
-        m_devices.append(dev);
+        connect(dev.get(), &KWinWaylandDevice::needsSaveChanged, this, &InputBackend::needsSaveChanged);
         qCDebug(KCM_MOUSE).nospace() << "Device connected: " << dev->name() << " (" << dev->sysName() << ")";
+        m_devices.push_back(std::move(dev));
         Q_EMIT deviceAdded(true);
-        Q_EMIT devicesChanged();
+        Q_EMIT inputDevicesChanged();
+
+        if (dev->isSaveNeeded()) {
+            Q_EMIT needsSaveChanged();
+        }
     }
 }
 
 void KWinWaylandBackend::onDeviceRemoved(QString sysName)
 {
-    QList<QObject *>::const_iterator it = std::find_if(m_devices.constBegin(), m_devices.constEnd(), [sysName](QObject *t) {
-        return static_cast<KWinWaylandDevice *>(t)->sysName() == sysName;
+    const auto it = std::ranges::find_if(std::as_const(m_devices), [sysName](const std::unique_ptr<KWinWaylandDevice> &device) {
+        return device->sysName() == sysName;
     });
     if (it == m_devices.cend()) {
         return;
     }
+    int index = std::distance(m_devices.cbegin(), it);
+
+    // delete at the end of the function, after change signals have been fired
+    std::unique_ptr<KWinWaylandDevice> dev = std::move(m_devices[index]);
+    m_devices.erase(m_devices.cbegin() + index);
+
+    bool deviceNeededSave = dev->isSaveNeeded();
+    disconnect(dev.get(), nullptr, this, nullptr);
 
-    KWinWaylandDevice *dev = static_cast<KWinWaylandDevice *>(*it);
     qCDebug(KCM_MOUSE).nospace() << "Device disconnected: " << dev->name() << " (" << dev->sysName() << ")";
 
-    int index = it - m_devices.cbegin();
-    m_devices.removeAt(index);
     Q_EMIT deviceRemoved(index);
-    Q_EMIT devicesChanged();
+    Q_EMIT inputDevicesChanged();
+
+    if (deviceNeededSave) {
+        Q_EMIT needsSaveChanged();
+    }
 }
 
-QList<QObject *> KWinWaylandBackend::getDevices() const
+QList<InputDevice *> KWinWaylandBackend::inputDevices() const
 {
-    return m_devices;
+    QList<InputDevice *> devices;
+    devices.reserve(m_devices.size());
+    for (const auto &device : m_devices) {
+        devices.append(device.get());
+    }
+    return devices;
 }
 
 int KWinWaylandBackend::deviceCount() const
 {
-    return m_devices.count();
+    return m_devices.size();
 }
 
 QString KWinWaylandBackend::errorString() const
