@@ -31,7 +31,7 @@ KNetAttach::KNetAttach(QWidget *parent)
     connect(_connectionName, &QLineEdit::textChanged, this, &KNetAttach::updateParametersPageStatus);
     connect(_user, &QLineEdit::textChanged, this, &KNetAttach::updateParametersPageStatus);
     connect(_host, &QLineEdit::textChanged, this, &KNetAttach::updateParametersPageStatus);
-    connect(_port, (void (QSpinBox::*)(int)) & QSpinBox::valueChanged, this, &KNetAttach::updateParametersPageStatus);
+    connect(_port, (void(QSpinBox::*)(int)) & QSpinBox::valueChanged, this, &KNetAttach::updateParametersPageStatus);
     connect(_path, &QLineEdit::textChanged, this, &KNetAttach::updateParametersPageStatus);
     connect(_useEncryption, &QAbstractButton::toggled, this, &KNetAttach::updatePort);
     connect(_createIcon, &QAbstractButton::toggled, this, &KNetAttach::updateFinishButtonText);
@@ -193,12 +193,10 @@ bool KNetAttach::validateCurrentPage()
             url.setUserName(trimmedUser);
         }
         QString path = _path->text().trimmed();
-#ifndef Q_WS_WIN
         // could a relative path really be made absolute by simply prepending a '/' ?
         if (!path.startsWith(QLatin1Char('/'))) {
             path = QLatin1Char('/') + path;
         }
-#endif
         url.setPath(path);
         _folderParameters->setEnabled(false);
         bool success = doConnectionTest(url);
